@@ -20,10 +20,12 @@ from litepipeline.manager.handlers import schedule
 from litepipeline.manager.utils.listener import Connection
 from litepipeline.manager.utils.listener import DiscoveryListener
 from litepipeline.manager.models.applications import Applications
+from litepipeline.manager.models.application_history import ApplicationHistory
 from litepipeline.manager.models.tasks import Tasks
 from litepipeline.manager.models.workflows import Workflows
 from litepipeline.manager.models.works import Works
 from litepipeline.manager.models.schedules import Schedules
+from litepipeline.manager.utils.app_manager import AppManager
 from litepipeline.manager.utils.scheduler import Scheduler
 from litepipeline.manager.utils import common
 from litepipeline.manager.utils.litedfs import LDFS, LiteDFS
@@ -44,6 +46,10 @@ class Application(tornado.web.Application):
             (r"/app/update", application.UpdateApplicationHandler),
             (r"/app/info", application.InfoApplicationHandler),
             (r"/app/download", application.DownloadApplicationHandler),
+            (r"/app/history/list", application.ApplicationHistoryListHandler),
+            (r"/app/history/info", application.ApplicationHistoryInfoHandler),
+            (r"/app/history/activate", application.ApplicationHistoryActivateHandler),
+            (r"/app/history/delete", application.ApplicationHistoryDeleteHandler),
             (r"/task/create", task.CreateTaskHandler),
             (r"/task/list", task.ListTaskHandler),
             (r"/task/info", task.InfoTaskHandler),
@@ -104,9 +110,11 @@ def main():
                     LDFS = LiteDFS(CONFIG["ldfs_http_host"], CONFIG["ldfs_http_port"])
                 tasks_db = Tasks()
                 applications_db = Applications()
+                application_history_db = ApplicationHistory()
                 workflows_db = Workflows()
                 works_db = Works()
                 schedules_db = Schedules()
+                app_manager = AppManager()
                 task_scheduler = Scheduler(CONFIG["scheduler_interval"])
                 http_server = tornado.httpserver.HTTPServer(
                     Application(),
@@ -119,10 +127,12 @@ def main():
                 listener.listen(CONFIG["tcp_port"], CONFIG["tcp_host"])
                 common.Servers.HTTP_SERVER = http_server
                 common.Servers.SERVERS.append(applications_db)
+                common.Servers.SERVERS.append(application_history_db)
                 common.Servers.SERVERS.append(tasks_db)
                 common.Servers.SERVERS.append(workflows_db)
                 common.Servers.SERVERS.append(works_db)
                 common.Servers.SERVERS.append(schedules_db)
+                common.Servers.SERVERS.append(app_manager)
                 common.Servers.SERVERS.append(task_scheduler)
                 signal.signal(signal.SIGTERM, common.sig_handler)
                 signal.signal(signal.SIGINT, common.sig_handler)
