@@ -23,3 +23,15 @@ class ApplicationHandler(BaseHandler):
                 CONFIG["manager_http_host"],
                 CONFIG["manager_http_port"])
         )
+
+
+class ApplicationInfoHandler(BaseHandler):
+    @gen.coroutine
+    def get(self, app_id):
+        self.render(
+            "application/application_info.html",
+            app_id = app_id,
+            manager_host = "%s:%s" % (
+                CONFIG["manager_http_host"],
+                CONFIG["manager_http_port"])
+        )
